@@ -1126,11 +1126,11 @@ def update_form_hgnc_symbols(store, case_obj, form):
         # if symbols are numeric HGNC id, translate to current symbols
         for hgnc_symbol in form.hgnc_symbols.data:
             if hgnc_symbol.isdigit():
-                hgnc_gene = store.hgnc_gene(int(hgnc_symbol), genome_build)
-                if hgnc_gene is None:
+                hgnc_gene_caption = store.hgnc_gene_caption(int(hgnc_symbol), genome_build)
+                if hgnc_gene_caption is None:
                     not_found_ids.append(hgnc_symbol)
                 else:
-                    hgnc_symbols.append(hgnc_gene["hgnc_symbol"])
+                    hgnc_symbols.append(hgnc_gene_caption.get("hgnc_symbol", hgnc_symbol))
             else:
                 hgnc_symbols.append(hgnc_symbol)
 
@@ -1230,7 +1230,9 @@ def reset_all_dimissed(store, institute_obj, case_obj):
         institute_obj(dict): an institute dictionary
         case_obj(dict): a case dictionary
     """
-    evaluated_vars = store.evaluated_variants(case_id=case_obj["_id"])
+    evaluated_vars = store.evaluated_variants(
+        case_id=case_obj["_id"], institute_id=case_obj["owner"]
+    )
     user_obj = store.user(current_user.email)
     # Create an associated case-level event
     link = url_for(
