@@ -66,9 +66,36 @@ function populateCytobands(cytobands){
   }
 }
 
+function validateChromPos(){
+  // Validate Chromosome position form
+  //Expected format: <chr number>:<start>-<end>[+-]?<padding>
+  var chrPosPattern = "^(?:chr)?([1-9]|1[0-9]|2[0-2]|X|Y|MT)(?::([0-9]+)-([0-9]+)([+-]{1}[0-9]+)?)?$";
+  var chromoPosField = document.forms["filters_form"].elements["chrom_pos"]
+  if (chromoPosField && chromoPosField.vaLue) {
+    var chrom_pos = chromoPosField.value.replaceAll(',', '')
+    if (!RegExp(chrPosPattern).test(chrom_pos)) {
+      alert("Invalid format of chromosome position, expected format <chr number>:<start>-<end>[+-]?<padding>");
+      return false;
+    }
+    var chromPosMatch  = chrom_pos.match(chrPosPattern);
+    var start = chromPosMatch[2];
+    var end = chromPosMatch[3];
+    var padding = chromPosMatch[5];
+    if (Number(start) < 0 || Number(end) < 0) {
+      alert("Invalid coordinates, coordinates must be greater than zero");
+      return false;
+    } else if (Number(start) > Number(end)) {
+      alert("Invalid coordinates, end coordinate must be greater than start");
+      return false;
+    } else if (Number(padding) < 1) {
+      alert("Padding must be greater than zero!")
+    }
+  }
+}
+
 /* exported validateForm */
 // ValidateForm()
-// Controll user input fields (start, end) in varaint filter.
+// Control user input fields (start, end) in variant filter.
 // Verify the format of Chromosome position
 //
 function validateForm(){
@@ -88,29 +115,9 @@ function validateForm(){
       return false;
     }
   }
-  // Validate Chromosome position form
-  //Expected format: <chr number>:<start>-<end>[+-]?<padding>
-  var chrom_pos = document.forms["filters_form"].elements["chrom_pos"].value.replaceAll(',', '')
-  var chrPosPattern = "^(?:chr)?([1-9]|1[0-9]|2[0-2]|X|Y|MT)(?::([0-9]+)-([0-9]+)([+-]{1}[0-9]+)?)?$";
-  if(chrom_pos) {
-    if (!RegExp(chrPosPattern).test(chrom_pos)) {
-      alert("Invalid format of chromosome position, expected format <chr number>:<start>-<end>[+-]?<padding>");
-      return false;
-    }
-    var chromPosMatch  = chrom_pos.match(chrPosPattern);
-    var start = chromPosMatch[2];
-    var end = chromPosMatch[3];
-    var padding = chromPosMatch[5];
-    if (Number(start) < 0 || Number(end) < 0) {
-      alert("Invalid coordinates, coordinates must be greater than zero");
-      return false;
-    } else if (Number(start) > Number(end)) {
-      alert("Invalid coordinates, end coordinate must be greater than start");
-      return false;
-    } else if (Number(padding) < 1) {
-      alert("Padding must be greater than zero!")
-    }
-  }
+  validateChromPos();
+  // Avoid page spinner being stuck on Filter and export variants option
+  $(window).unbind('beforeunload');
   return true;
 }
 
