@@ -746,7 +746,6 @@ def gene_database(request, institute_database, genes):
 
 @pytest.fixture(scope="function")
 def real_gene_database(
-    request,
     real_institute_database,
     genes37_handle,
     hgnc_handle,
@@ -815,7 +814,7 @@ def populated_database(request, panel_database, parsed_case):
 
 
 @pytest.fixture(scope="function")
-def real_populated_database(request, real_panel_database, parsed_case):
+def real_populated_database(real_panel_database, parsed_case):
     "Returns an adapter to a database populated with user, institute case, genes, panels"
     adapter = real_panel_database
 
